@@ -21,7 +21,7 @@ class InstagramBackend(OAuthBackend):
     def get_user_details(self, response):
         """Return user details from Instagram account"""
         username = response['user']['username']
-        fullname = response['user'].get('fullname', '')
+        fullname = response['user'].get('full_name', '')
         email = response['user'].get('email', '')
         return {
             USERNAME: username,
